Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetVersion ¶
GetVersion returns the kude version currently running.
Types ¶
type GitRepositoryReconciler ¶
type GitRepositoryReconciler struct {
Client client.Client // Kubernetes API client
Recorder record.EventRecorder // Kubernetes event recorder
Scheme *runtime.Scheme // Scheme registry
WorkDir string // Working directory for the controller
}
GitRepositoryReconciler reconciles a GitRepository object
func (*GitRepositoryReconciler) Reconcile ¶
func (r *GitRepositoryReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile continuously aims to move the current state of [GitRepository] objects closer to their desired state.
func (*GitRepositoryReconciler) SetupWithManager ¶
func (r *GitRepositoryReconciler) SetupWithManager(mgr ctrl.Manager) error
type KubectlBundleReconciler ¶
type KubectlBundleReconciler struct {
Client client.Client // Kubernetes API client
Recorder record.EventRecorder // Kubernetes event recorder
Scheme *runtime.Scheme // Scheme registry
}
KubectlBundleReconciler reconciles a KubectlBundle object
func (*KubectlBundleReconciler) Reconcile ¶
func (r *KubectlBundleReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile continuously aims to move the current state of [KubectlBundle] objects closer to their desired state.
func (*KubectlBundleReconciler) SetupWithManager ¶
func (r *KubectlBundleReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package v1alpha1 contains API Schema definitions for the kude.kfirs.com/v1alpha1 API group +kubebuilder:object:generate=true +groupName=kude.kfirs.com
|
Package v1alpha1 contains API Schema definitions for the kude.kfirs.com/v1alpha1 API group +kubebuilder:object:generate=true +groupName=kude.kfirs.com |
Click to show internal directories.
Click to hide internal directories.